<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="41"/>
        <source>License</source>
        <translation>Licenc</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <location filename="../about.cpp" line="52"/>
        <source>Changelog</source>
        <translation>Változások listája</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="43"/>
        <source>Cancel</source>
        <translation>Mégsem</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation>&amp;Bezárás</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="47"/>
        <source>GUI for applying assorted useful tweaks</source>
        <translation>Grafikus felhasználói felület különféle hasznos módosítások elvégzéséhez</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>launches brightness-systray</source>
        <translation>Elindítja a fényerősség tálcaalkalmazást</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>opens with display tab open.  Only valid with Xfce desktop running</source>
        <translation>a megjelenítés lappal megnyitva nyílik meg. Csak Xfce asztali környezet futása esetén érvényes</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Opens theme tab directly.  Valid on Xfce &amp; Fluxbox desktops</source>
        <translation>A témák lappal nyílik meg. Csak Xfce és Fluxbox asztali környezetek esetén érvényes</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Opens Other tab directly.  Valid on all desktops</source>
        <translation>Az egyéb lappal nyílik meg. Minden asztali környezetnél érvényes</translation>
    </message>
</context>
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation>MainWindow</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="39"/>
        <source>Save</source>
        <translation>Mentés</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="59"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Szoftveres fényerősség (xrandr)</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="66"/>
        <location filename="../brightness_small.ui" line="87"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="80"/>
        <source>Hardware Backlight</source>
        <translation>Hardveres háttérvilágítás</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="94"/>
        <source>&gt;&gt;</source>
        <translation>&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="33"/>
        <source>MX-Tweak</source>
        <translation>MX finomhangoló</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="58"/>
        <source>Display</source>
        <translation>Megjelenés</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="63"/>
        <source>&amp;Quit</source>
        <translation>&amp;Kilépés</translation>
    </message>
</context>
<context>
    <name>defaultlook</name>
    <message>
        <location filename="../defaultlook.ui" line="20"/>
        <location filename="../defaultlook.cpp" line="56"/>
        <location filename="../defaultlook.cpp" line="85"/>
        <location filename="../defaultlook.cpp" line="648"/>
        <location filename="../defaultlook.cpp" line="667"/>
        <location filename="../defaultlook.cpp" line="676"/>
        <location filename="../defaultlook.cpp" line="723"/>
        <location filename="../defaultlook.cpp" line="731"/>
        <location filename="../defaultlook.cpp" line="758"/>
        <location filename="../defaultlook.cpp" line="761"/>
        <source>MX Tweak</source>
        <translation>MX finomhangoló</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="41"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;A panel testreszabása&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="51"/>
        <location filename="../defaultlook.ui" line="272"/>
        <source>Panel</source>
        <translation>Panel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="71"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Ablakok működésének beállítása és gyorsbillentyűk&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="85"/>
        <source>Window Manager</source>
        <translation>Ablakkezelő</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="105"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Az asztal kinézetének testreszabása&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="119"/>
        <source>Appearance</source>
        <translation>Megjelenés</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="133"/>
        <source>Xfce Settings</source>
        <translation>Xfce beállítások</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="212"/>
        <source>About</source>
        <translation>Névjegy</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="223"/>
        <source>Help</source>
        <translation>Súgó</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="240"/>
        <source>Quit application</source>
        <translation>Kilépés az alkalmazásból</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="243"/>
        <source>Close</source>
        <translation>Bezárás</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="250"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="283"/>
        <source>Display panel horizontally</source>
        <translation>Panel megjelenítése vízszintesen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="293"/>
        <source>Volume</source>
        <translation>Kötet</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="300"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Docklike&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Docklike&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="307"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Minden panelre hatással van&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="327"/>
        <location filename="../defaultlook.ui" line="1698"/>
        <source>Bottom</source>
        <translation>Lent</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="332"/>
        <location filename="../defaultlook.ui" line="1708"/>
        <source>Top</source>
        <translation>Fent</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="340"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Tasklist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Feladatlista&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="347"/>
        <source>Display panel vertically</source>
        <translation>Panel megjelenítése függőlegesen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="362"/>
        <location filename="../defaultlook.ui" line="1726"/>
        <source>Affects 1st panel</source>
        <translation>Az első panelre van hatással</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="369"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Panel Plugin Scales&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:700;&quot;&gt;Panelbővítmények méretezése&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="389"/>
        <source>Backup current panel configuration</source>
        <translation>A jelenlegi panelbeállítások mentése</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="399"/>
        <location filename="../defaultlook.ui" line="459"/>
        <source>Options</source>
        <translation>Beállítások</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="419"/>
        <source>Power Manager</source>
        <translation>Energiakezelés</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="426"/>
        <source>Restore backup panel configuration</source>
        <translation>A panelbeállítások visszaállítása mentésből</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="449"/>
        <source>Set Scales</source>
        <translation>Méretezés beállítása</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="479"/>
        <location filename="../defaultlook.ui" line="1703"/>
        <source>Left</source>
        <translation>Balra</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="484"/>
        <location filename="../defaultlook.ui" line="1713"/>
        <source>Right</source>
        <translation>Jobbra</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="492"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ablakgombok&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="513"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Docklike is the modern dock plugin for the panel.  Window Buttons is the classic tasklist without dock features.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;A Docklike a modern dokk bővítmény a panelhez. Az Ablakgombok a feladatlista feladatlista, dokk funkciók nélkül.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="536"/>
        <location filename="../defaultlook.ui" line="630"/>
        <location filename="../defaultlook.ui" line="889"/>
        <location filename="../defaultlook.ui" line="1057"/>
        <location filename="../defaultlook.ui" line="1064"/>
        <location filename="../defaultlook.ui" line="1071"/>
        <location filename="../defaultlook.ui" line="1138"/>
        <location filename="../defaultlook.ui" line="1413"/>
        <location filename="../defaultlook.ui" line="1739"/>
        <location filename="../defaultlook.ui" line="1863"/>
        <source>Apply</source>
        <translation>Alkalmazás</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="556"/>
        <source>Restore default panel</source>
        <translation>Alapértelmezett panel visszaállítása</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="566"/>
        <source>Set Tasklist plugin to:</source>
        <translation>Feladatlista bővítmény beállítása:</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="580"/>
        <source>Theme</source>
        <translation>Téma</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="596"/>
        <source>Theme Options</source>
        <translation>Téma beállítások</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="606"/>
        <source>Remove User Theme Set</source>
        <translation>Felhasználói témakészlet eltávolítása</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="617"/>
        <source>Preview</source>
        <translation>Előnézet</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="656"/>
        <source>Undo</source>
        <translation>Visszavonás</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="666"/>
        <source>Save Current Settings as a Theme Set</source>
        <translation>A jelenlegi beállítások mentése mint témakészlet</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="687"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Cursors&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Kurzorok&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="694"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Manager&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ablakkezelő&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="704"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Application&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Alkalmazás&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="711"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ikonok&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="728"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Themes&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Témák&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="738"/>
        <location filename="../defaultlook.ui" line="756"/>
        <source>Compositor</source>
        <translation>Compositor</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="749"/>
        <source>Transparency and shadow options</source>
        <translation>Átlátszóság és árnyék beállítások</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="763"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>A compton.conf szerkesztése szövegszerkesztőben</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="766"/>
        <source>Edit compton.conf</source>
        <translation>A compton.conf szerkesztése</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="777"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor beállítások&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="780"/>
        <source>Xfwm Settings</source>
        <translation>Xfwm beállítások</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="791"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;A VBlank üzemmód megváltoztatása segíthet enyhíteni a képernyőszaggatással kapcsolatos problémákat. További információkat a Súgóban talál.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="794"/>
        <source>VBlank</source>
        <translation>VBlank</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="801"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>A Compton-conf beállító eszköz indítása</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="804"/>
        <source>Compton settings</source>
        <translation>Compton beállítások</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="828"/>
        <source>None</source>
        <translation>Nincs</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="833"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Xfwm (Xfce) Compositor</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="838"/>
        <source>Compton </source>
        <translation>Compton</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="847"/>
        <source>auto</source>
        <translation>automatikus</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="852"/>
        <source>glx</source>
        <translation>glx</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="857"/>
        <source>xpresent</source>
        <translation>xpresent</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="862"/>
        <source>off</source>
        <translation>ki</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="912"/>
        <source>Display</source>
        <translation>Megjelenés</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="923"/>
        <source>Hardware Backlight</source>
        <translation>Hardveres háttérvilágítás</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="930"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Display Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Megjelenés finomhangolása&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="957"/>
        <source>Choose Display for xrandr tweaks</source>
        <translation>Válasszon kijelzőt az xrandr finomhangoláshoz</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="967"/>
        <source>Resolution</source>
        <translation>Felbontás</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="974"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving is per display&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;A mentés kijelzőnként történik&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="977"/>
        <source>Save</source>
        <translation>Mentés</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="984"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Szoftveres fényerősség (xrandr)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="991"/>
        <location filename="../defaultlook.ui" line="1088"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="998"/>
        <source>GTK scaling</source>
        <translation>GTK nagyítás</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1018"/>
        <source>xrandr Scaling</source>
        <translation>xrandr nagyítás</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1114"/>
        <source>Config Options</source>
        <translation>Beállítási lehetőségek</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1125"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation>A hosszú fájlnevek lerövidítésének letiltása az asztalon</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1149"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>                   megjegyzés: a hibernáláshoz a cserehely &gt;= RAM</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1169"/>
        <source>Enable single-click on desktop</source>
        <translation>Egyszeres kattintás bekapcsolása az asztalon</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1176"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>Hibernálás engedélyezése a kijelentkezés menün</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1183"/>
        <location filename="../defaultlook.ui" line="1531"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation>Az egyéni Thunar jobb-gomb kattintás műveletek visszaállítása alapértelmezettre</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1190"/>
        <location filename="../defaultlook.ui" line="1386"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Egyszeres kattintás engedélyezése a Thunar fájlkezelőben</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1197"/>
        <location filename="../defaultlook.ui" line="1567"/>
        <source>Thunar windows always open in split view</source>
        <translation>A Thunar ablakok mindig osztott nézetben nyílnak meg</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1204"/>
        <location filename="../defaultlook.ui" line="1487"/>
        <source>Thunar split view opens horizontal</source>
        <translation>A Thunar osztott nézet vízszintesen nyílik meg</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1211"/>
        <source>Show percentages in notifcations when available</source>
        <translation>Százalék megjelenítése az értesítésben, ha rendelkezésre áll</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1218"/>
        <source>Enable Desktop Zoom </source>
        <translation>Asztal nagyítás engedélyezése</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1225"/>
        <location filename="../defaultlook.ui" line="1788"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>Az összes munkaasztal ablakainak megjelenítése a panelen</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1232"/>
        <source>Show GTK File Dialog action buttons at bottom of dialogs</source>
        <translation>A GTK fájl ablak műveleteinek megjelenítése a dialógusablakok alján</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1239"/>
        <source>( also turns off Client Side Decorations for Xfce applications)</source>
        <translation>(kikacsolja az Xfce alkalmazások Kliensoldali Dekorációját (CSD) is)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1252"/>
        <source>Fluxbox</source>
        <translation>Fluxbox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1263"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Dock Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Dokk beállítások&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1271"/>
        <location filename="../defaultlook.ui" line="1542"/>
        <source>On</source>
        <translation>Be</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1276"/>
        <location filename="../defaultlook.ui" line="1547"/>
        <source>Off</source>
        <translation>Ki</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1294"/>
        <source>Manage Tint2 Panel</source>
        <translation>Tint2 panel kezelése</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1305"/>
        <source>Height</source>
        <translation>Magasság</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1379"/>
        <location filename="../defaultlook.ui" line="1608"/>
        <source>Autohide</source>
        <translation>Automatikus elrejtés</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1393"/>
        <location filename="../defaultlook.ui" line="1635"/>
        <location filename="../defaultlook.ui" line="1687"/>
        <source>Placement</source>
        <translation>Elhelyezés</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1400"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Thunar&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Thunar&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1494"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Desktop Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Asztali ikonok&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1511"/>
        <source>Toggle icon captions</source>
        <translation>Ikon feliratok ki-/bekapcsolása</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1552"/>
        <source>On Hover</source>
        <translation>Egér alatt</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1560"/>
        <source>Toggle desktop icons</source>
        <translation>Asztali ikonok ki-/bekapcsolása</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1574"/>
        <location filename="../defaultlook.ui" line="1802"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Reset Defaults&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Alapértékek visszaállítása&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1594"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Toolbar Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Eszköztár beállítások&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1601"/>
        <source>Width</source>
        <translation>Szélesség</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1615"/>
        <source>Show Toolbar</source>
        <translation>Eszköztár megjelenítése</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1642"/>
        <source>Reset DefaultDock</source>
        <translation>Alapértelmezett dokk visszaállítása</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1649"/>
        <source>Reset Fluxbox Menu</source>
        <translation>Fluxbox menü visszaállítása</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1656"/>
        <source>Reset ALL mx-fluxbox settings</source>
        <translation>MINDEN mx-fluxbox beállítás visszaállítása</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1663"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Add new default menu items, if any, to existing fluxbox menu.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Új alapértelmezett elemek hozzáadása a  meglévő fluxbox menühöz, ha vannak.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1666"/>
        <source>Upgrade existing menu entries</source>
        <translation>Jelenlegi menüelemek frissítése</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1676"/>
        <source>Plasma</source>
        <translation>Plazma</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1755"/>
        <source>Workspace</source>
        <translation>Munkaterület</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1795"/>
        <source>Enable single-click</source>
        <translation>Egyszeres kattintás engedélyezése</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1809"/>
        <source>Reset KDE/Plasma defaults</source>
        <translation>KDE/Plazma alapértékek visszaállítása</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1819"/>
        <source>Other</source>
        <translation>Egyéb</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1843"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>A Lightdm (bejelentkező képernyő) visszaállítása az alap témára</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1850"/>
        <source>Password for administrative tasks:</source>
        <translation>Jelszó adminisztratív feladatokhoz:</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1881"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>A belső eszközök csatolásának engedélyezése nem-root felhasználók számára</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1888"/>
        <source>Root</source>
        <translation>Root</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1895"/>
        <source>Enable kernel sandbox</source>
        <translation>A kernel sandbox engedélyezése</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1902"/>
        <source>&amp;User</source>
        <translation>&amp;Felhasználó</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1909"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;requires reboot&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;újraindítás szükséges&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1912"/>
        <source>Enable Bluetooth Adapters on boot</source>
        <translation>Bluetooth eszközök engedélyezése indításkor</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1919"/>
        <source>Apt installs additional &quot;recommends&quot; packages as dependencies</source>
        <translation>Az Apt telepíti a további &quot;javasolt&quot; csomagokat, mint függőség</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1926"/>
        <source>Generate fluxbox All Apps menu after package installation, removal, and updates</source>
        <translation>A Fluxbox alkalmazások menüjének frissítése csomagok telepítése, eltávolítása vagy frissítése után</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1933"/>
        <source>Use Client Side Decorations (CSD) on GTK3 applications that support them (requires session restart)</source>
        <translation>Kliensoldali Dekorációk (CSD) használata a GTK3 alkalmazásokban, amelyek támogatják (munkafolyamat újraindítása szükséges)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1940"/>
        <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
        <translation>Az intel illesztőprogram használata az alap &quot;modesetting&quot; illesztőprogram helyett (újraindítás szükséges)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1947"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>          Megjegyzés: a meglévő /etc/X11/xorg.conf.d/20-intel.conf a saját-könyvtárban kerül mentésre</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1954"/>
        <source>Use tearfree amdgpu option</source>
        <translation>A tearfree amdgpu opció használata</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1961"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>          Megjegyzés: a meglévő /etc/X11/xorg.conf.d/20-amd.conf a saját-könyvtárban kerül mentésre</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1968"/>
        <source>Use tearfree radeon driver option</source>
        <translation>A tearfree radeon illesztőprogram opció használata</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1975"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>          Megjegyzés: a meglévő /etc/X11/xorg.conf.d/20-radeon.conf a saját-könyvtárban kerül mentésre</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="57"/>
        <source>--display switch only valid for Xfce</source>
        <translation>--display kapcsoló csak Xfce-hez érvényes</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="647"/>
        <source>About MX Tweak</source>
        <translation>Az MX finomhangolóról</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="649"/>
        <source>Version: </source>
        <translation>Verzió:</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="650"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>Alkalmazás a felhasználó felület gyors beállításához és finomhangolásához</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="652"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="653"/>
        <source>%1 License</source>
        <translation>%1 licenc</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="667"/>
        <source>%1 Help</source>
        <translation>%1 Súgó</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="677"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation>Kész! A változtatások alkalmazásához a Firefox újraindítása lehet szükséges</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="724"/>
        <source>Plese remove special characters</source>
        <translation>Távolítsa el a speciális karaktereket</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="724"/>
        <source>from file name</source>
        <translation>a fájlnévből</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="731"/>
        <source>File name already exists.  Choose another name</source>
        <translation>A fájlnév már létezik. Válasszon másik nevet</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="759"/>
        <source>File is not a valid tar.xz archive file</source>
        <translation>A fájl nem egy érvényes tar.xz archívum</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="762"/>
        <source>Archive does not contain a panel config</source>
        <translation>Az archívum nem panelbeállításokat tartalmaz</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="937"/>
        <source>Panel settings</source>
        <translation>Panelbeállítások</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="938"/>
        <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation>Az aktuális panelbeállításokról biztonsági másolat készült egy rejtett .restore nevű mappába a saját mappájában (~/.restore/).</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1715"/>
        <source>settings</source>
        <translation>beállítások</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="2055"/>
        <source>Choose a theme set</source>
        <translation>Válasszon egy témakészletet</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>Felhasználói témakészlet eltávolítása</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation>Új témakészlet</translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation>Adjon meg egy nevet az új témakészletnek</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="24"/>
        <source>Window Buttons</source>
        <translation>Ablakgombok</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Megjelenés&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation>Gombfeliratok megjelenítése</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation>Lapos gombok megjelenítése</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation>Fogantyú megjelenítése</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation>Rendezési sorrend:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation>Időbélyeg</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation>Csoport címe és időbélyege</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation>Ablakcím</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation>Csoport címe és ablakcíme</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation>Nincs, fogd és vidd engedélyezése</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Viselkedés&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>Ablakcsoportosítás:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>Soha</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>Mindig</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>Középső egérgomb művelete:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>Semmi</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>Ablak bezárása</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>Ablak minimalizálása</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Minimalizált ablakok visszaállítása az aktuális munkaterületre</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Ablakkeret rajzolása egy gombra mutatáskor</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>Ablakok közti váltás egérgörgővel</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Szűrés&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>Minden munkaterület vagy munkalap ablakainak megjelenítése</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation>Csak minimalizált ablakok megjelenítése</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation>Az összes monitor ablakainak megjelenítése</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>Bezárás</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialógus</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation>Felugró ablakok</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation>Ablakok mozgatás közben</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Átlátszósági beállítások&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation>Ablakdekorációk</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>Árnyék megjelenítése a dokkablakok alatt</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation>Árnyék megjelenítése a felugró ablakok alatt</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation>Ablakok átméretezés közben</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>Árnyék megjelenítése az általános ablakok alatt</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Funkció beállítások&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>Ablak előnézetek megjelenítése ikonok helyett a választás közben</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>Teljes képernyős lefedő ablakok közvetlen megjelenítése</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation>Interaktív ablakok</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>A frissítés szinkronizálása a monitor frissítéséhez</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>Bezárás</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="23"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Xfwm Compositor beállítások</translation>
    </message>
</context>
</TS>
